Struct frame_benchmarking_cli::BenchmarkCmd [−][src]
pub struct BenchmarkCmd {Show fields
pub pallet: Option<String>,
pub extrinsic: Option<String>,
pub steps: u32,
pub lowest_range_values: Vec<u32>,
pub highest_range_values: Vec<u32>,
pub repeat: u32,
pub external_repeat: u32,
pub raw_data: bool,
pub no_median_slopes: bool,
pub no_min_squares: bool,
pub output: Option<PathBuf>,
pub header: Option<PathBuf>,
pub template: Option<PathBuf>,
pub output_analysis: Option<String>,
pub heap_pages: Option<u64>,
pub no_verify: bool,
pub extra: bool,
pub record_proof: bool,
pub shared_params: SharedParams,
pub execution: Option<ExecutionStrategy>,
pub wasm_method: WasmExecutionMethod,
pub database_cache_size: u32,
pub list: bool,
}Expand description
The benchmark command used to benchmark FRAME Pallets.
Fields
pallet: Option<String>Select a FRAME Pallet to benchmark, or * for all (in which case extrinsic must be *).
extrinsic: Option<String>Select an extrinsic inside the pallet to benchmark, or * for all.
steps: u32Select how many samples we should take across the variable components.
lowest_range_values: Vec<u32>Indicates lowest values for each of the component ranges.
highest_range_values: Vec<u32>Indicates highest values for each of the component ranges.
repeat: u32Select how many repetitions of this benchmark should run from within the wasm.
external_repeat: u32Select how many repetitions of this benchmark should run from the client.
NOTE: Using this alone may give slower results, but will afford you maximum Wasm memory.
raw_data: boolPrint the raw results.
no_median_slopes: boolDon’t print the median-slopes linear regression analysis.
no_min_squares: boolDon’t print the min-squares linear regression analysis.
output: Option<PathBuf>Output the benchmarks to a Rust file at the given path.
header: Option<PathBuf>Add a header file to your outputted benchmarks
template: Option<PathBuf>Path to Handlebars template file used for outputting benchmark results. (Optional)
output_analysis: Option<String>Which analysis function to use when outputting benchmarks:
- min-squares (default)
- median-slopes
- max (max of min squares and median slopes for each value)
heap_pages: Option<u64>Set the heap pages while running benchmarks. If not set, the default value from the client is used.
no_verify: boolDisable verification logic when running benchmarks.
extra: boolDisplay and run extra benchmarks that would otherwise not be needed for weight construction.
record_proof: boolEstimate PoV size.
execution: Option<ExecutionStrategy>The execution strategy that should be used for benchmarks
wasm_method: WasmExecutionMethodMethod for executing Wasm runtime code.
database_cache_size: u32Limit the memory the database cache can use.
list: boolList the benchmarks that match your query rather than running them.
When nothing is provided, we list all benchmarks.
Implementations